@@ -15,11 +15,11 @@ from ama_xiv_combat_sim.simulator.timeline_builders.rotation_builder import (
 from ama_xiv_combat_sim.simulator.utils import Utils
 
 
-class TestJobs(TestClass):
+class TestJobs655(TestClass):
     def __init__(self):
         super().__init__()
         self.__skill_library = create_skill_library()
-        self.__relative_tol = 5e-3
+        self.__relative_tol = 6e-3
 
     def __test_skills(self, stats, skills_and_expected_damage):
         test_passed = True
@@ -575,7 +575,7 @@ class TestJobs(TestClass):
         rb.add_next("Assize")
         rb.add_next("Glare III", num_times=10)
         expected_damage = 301604.8
-        expected_total_time = 29480.0
+        expected_total_time = 29760.0
 
         return self.__test_aggregate_rotation(rb, expected_damage, expected_total_time)
 
@@ -598,7 +598,7 @@ class TestJobs(TestClass):
             ("Dosis III", SkillModifier(), 17275.3),
             ("Phlegma III", SkillModifier(), 31436.4),
             ("Toxikon II", SkillModifier(), 17284.2),
-            ("Dykrasia II", SkillModifier(), 8901.3),
+            ("Dyskrasia II", SkillModifier(), 8901.3),
             ("Pneuma", SkillModifier(), 17264.3),
             ("Eukrasian Dosis III", SkillModifier(), 39979.0),
         )
@@ -1622,7 +1622,7 @@ class TestJobs(TestClass):
             dh_stat=1380,
             speed_stat=436,
             job_class="DNC",
-            version="7.0",
+            version="6.55",
         )
         skills_and_expected_damage = (
             ("Auto", SkillModifier(), 3874.0),
