@@ -1,7 +1,9 @@
 import math
 
 from ama_xiv_combat_sim.simulator.calcs.damage_class import DamageClass
-from ama_xiv_combat_sim.simulator.game_data.patch_70.convenience_timings import get_auto_timing
+from ama_xiv_combat_sim.simulator.game_data.patch_70.convenience_timings import (
+    get_auto_timing,
+)
 from ama_xiv_combat_sim.simulator.sim_consts import SimConsts
 from ama_xiv_combat_sim.simulator.skills.skill import Skill
 from ama_xiv_combat_sim.simulator.specs.damage_spec import DamageSpec
@@ -15,7 +17,10 @@ from ama_xiv_combat_sim.simulator.specs.timing_spec import TimingSpec
 def add_blm_skills(skill_library):
     auto_timing = get_auto_timing()
     blm_caster_tax_ms = 100
-    instant_timing_spec = TimingSpec(base_cast_time=0, animation_lock=blm_caster_tax_ms)
+    base_animation_lock = 600
+    instant_timing_spec = TimingSpec(
+        base_cast_time=0, animation_lock=base_animation_lock + blm_caster_tax_ms
+    )
     skill_library.set_current_job_class("BLM")
 
     skill_library.set_status_effect_priority(("Swiftcast", "Triplecast"))
@@ -143,7 +148,7 @@ def add_blm_skills(skill_library):
 
         res[SimConsts.DEFAULT_CONDITION] = TimingSpec(
             base_cast_time=base_cast_time,
-            animation_lock=blm_caster_tax_ms,
+            animation_lock=base_animation_lock + blm_caster_tax_ms,
             application_delay=application_delay,
         )
         for elem_str in elem_strs:
@@ -154,7 +159,7 @@ def add_blm_skills(skill_library):
             )
             res[elem_str] = TimingSpec(
                 base_cast_time=int(cast_modifier * base_cast_time),
-                animation_lock=blm_caster_tax_ms,
+                animation_lock=base_animation_lock + blm_caster_tax_ms,
                 application_delay=application_delay,
             )
         return res
@@ -195,7 +200,7 @@ def add_blm_skills(skill_library):
     high_thunder_dot = Skill(
         name="Thunder (dot)",
         is_GCD=False,
-        damage_spec=DamageSpec(potency=50, damage_class=DamageClass.MAGICAL_DOT),
+        damage_spec=DamageSpec(potency=55, damage_class=DamageClass.MAGICAL_DOT),
     )
     high_thunder_follow_up = FollowUp(
         skill=high_thunder_dot,
@@ -215,8 +220,8 @@ def add_blm_skills(skill_library):
         dot_duration=24 * 1000,
         snapshot_buffs_with_parent=True,
         snapshot_debuffs_with_parent=True,
-    )    
-    
+    )
+
     skill_library.add_skill(
         Skill(
             name="Auto",
@@ -369,8 +374,13 @@ def add_blm_skills(skill_library):
             damage_spec=fire_damage_spec,
             timing_spec=fire_timing_spec,
             job_resource_spec=fire_job_resource_spec,
-            follow_up_skills={SimConsts.DEFAULT_CONDITION: (enochian_buff_follow_up,),
-                              "Firestarter Proc": (enochian_buff_follow_up, firestarter_follow_up,)}
+            follow_up_skills={
+                SimConsts.DEFAULT_CONDITION: (enochian_buff_follow_up,),
+                "Firestarter Proc": (
+                    enochian_buff_follow_up,
+                    firestarter_follow_up,
+                ),
+            },
         )
     )
     skill_library.add_skill(
@@ -383,7 +393,7 @@ def add_blm_skills(skill_library):
             },
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=blm_caster_tax_ms,
+                animation_lock=base_animation_lock + blm_caster_tax_ms,
                 application_delay=670,
             ),
         )
@@ -404,7 +414,9 @@ def add_blm_skills(skill_library):
         )
         fire_iii_damage_spec[assembled_str] = fire_iii_damage_spec[k]
         fire_iii_timing_spec[assembled_str] = TimingSpec(
-            base_cast_time=0, animation_lock=blm_caster_tax_ms, application_delay=1290
+            base_cast_time=0,
+            animation_lock=base_animation_lock + blm_caster_tax_ms,
+            application_delay=1290,
         )
     skill_library.add_skill(
         Skill(
@@ -432,7 +444,7 @@ def add_blm_skills(skill_library):
             ),
             timing_spec=get_enochian_timing_spec_cross(
                 base_cast_time=3500, is_fire_spell=False, application_delay=890
-            ),            
+            ),
             job_resource_spec=(
                 clear_astral_fire,
                 JobResourceSpec(
@@ -461,13 +473,13 @@ def add_blm_skills(skill_library):
             damage_spec=DamageSpec(potency=160),
             timing_spec=TimingSpec(
                 base_cast_time=2500,
-                animation_lock=blm_caster_tax_ms,
+                animation_lock=base_animation_lock + blm_caster_tax_ms,
                 application_delay=1030,
             ),
             follow_up_skills=(thunderiii_follow_up,),
         )
     )
-    
+
     flare_damage_spec = get_enochian_damage_spec_cross(
         base_potency=240, is_fire_spell=True
     )
@@ -535,7 +547,7 @@ def add_blm_skills(skill_library):
             damage_spec=DamageSpec(potency=80),
             timing_spec=TimingSpec(
                 base_cast_time=2500,
-                animation_lock=blm_caster_tax_ms,
+                animation_lock=base_animation_lock + blm_caster_tax_ms,
                 application_delay=1160,
             ),
             follow_up_skills=(thunderiv_follow_up,),
@@ -548,7 +560,7 @@ def add_blm_skills(skill_library):
             damage_spec=DamageSpec(potency=600),
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=blm_caster_tax_ms,
+                animation_lock=base_animation_lock + blm_caster_tax_ms,
                 application_delay=1160,
             ),
         )
@@ -581,7 +593,7 @@ def add_blm_skills(skill_library):
             damage_spec=DamageSpec(potency=880),
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=blm_caster_tax_ms,
+                animation_lock=base_animation_lock + blm_caster_tax_ms,
                 application_delay=620,
             ),
         )
@@ -616,7 +628,7 @@ def add_blm_skills(skill_library):
             ),
             timing_spec=get_enochian_timing_spec_cross(
                 base_cast_time=3000, is_fire_spell=False, application_delay=1160
-            ),            
+            ),
             job_resource_spec=(
                 clear_astral_fire,
                 JobResourceSpec(
@@ -626,27 +638,16 @@ def add_blm_skills(skill_library):
             follow_up_skills=(enochian_buff_follow_up,),
         )
     )
-
-    paradox_base_timing_spec = TimingSpec(
-        base_cast_time=2500, animation_lock=blm_caster_tax_ms, application_delay=670
-    )
-    paradox_umbral_timing_spec = TimingSpec(
-        base_cast_time=0, animation_lock=blm_caster_tax_ms, application_delay=670
-    )
     skill_library.add_skill(
         Skill(
             name="Paradox",
             is_GCD=True,
             damage_spec=DamageSpec(potency=500),
-            timing_spec={
-                SimConsts.DEFAULT_CONDITION: paradox_base_timing_spec,
-                "1 Astral Fire": paradox_base_timing_spec,
-                "2 Astral Fire": paradox_base_timing_spec,
-                "3 Astral Fire": paradox_base_timing_spec,
-                "1 Umbral Ice": paradox_umbral_timing_spec,
-                "2 Umbral Ice": paradox_umbral_timing_spec,
-                "3 Umbral Ice": paradox_umbral_timing_spec,
-            },
+            timing_spec=TimingSpec(
+                base_cast_time=0,
+                animation_lock=base_animation_lock + blm_caster_tax_ms,
+                application_delay=670,
+            ),
             job_resource_spec={
                 SimConsts.DEFAULT_CONDITION: tuple(),
                 "1 Astral Fire": (
@@ -702,7 +703,7 @@ def add_blm_skills(skill_library):
             damage_spec=DamageSpec(potency=200),
             timing_spec=TimingSpec(
                 base_cast_time=2500,
-                animation_lock=blm_caster_tax_ms,
+                animation_lock=base_animation_lock + blm_caster_tax_ms,
                 application_delay=1160,
             ),
             follow_up_skills=(high_thunder_follow_up,),
@@ -716,14 +717,14 @@ def add_blm_skills(skill_library):
             damage_spec=DamageSpec(potency=100),
             timing_spec=TimingSpec(
                 base_cast_time=2500,
-                animation_lock=blm_caster_tax_ms,
+                animation_lock=base_animation_lock + blm_caster_tax_ms,
                 application_delay=1160,
             ),
             follow_up_skills=(high_thunder_ii_follow_up,),
         )
     )
     flare_star_damage_spec = get_enochian_damage_spec_cross(
-        base_potency=350, is_fire_spell=True
+        base_potency=400, is_fire_spell=True
     )
     flare_star_timing_spec = get_enochian_timing_spec_cross(
         base_cast_time=3000, is_fire_spell=True, application_delay=1160
@@ -736,7 +737,7 @@ def add_blm_skills(skill_library):
             timing_spec=flare_star_timing_spec,
         )
     )
-    
+
     skill_library.add_skill(
         Skill(
             name="Swiftcast",
@@ -790,7 +791,7 @@ def add_blm_skills(skill_library):
                     "Despair",
                     "Flare",
                     "Paradox",
-                    "Flare Star"
+                    "Flare Star",
                 ),
             ),
         )
