@@ -35,7 +35,7 @@ def add_dnc_skills(skill_library):
             name="Cascade",
             is_GCD=True,
             combo_spec=(ComboSpec(),),
-            damage_spec=DamageSpec(potency=280),
+            damage_spec=DamageSpec(potency=220),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=800
             ),
@@ -47,8 +47,8 @@ def add_dnc_skills(skill_library):
             is_GCD=True,
             combo_spec=(ComboSpec(combo_actions=("Cascade",)),),
             damage_spec={
-                SimConsts.DEFAULT_CONDITION: DamageSpec(potency=340),
-                "No Combo": DamageSpec(potency=160),
+                SimConsts.DEFAULT_CONDITION: DamageSpec(potency=280),
+                "No Combo": DamageSpec(potency=120),
             },
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=980
@@ -71,10 +71,13 @@ def add_dnc_skills(skill_library):
             name="Standard Finish",
             is_GCD=False,
             buff_spec=StatusEffectSpec(
-                damage_mult=1.05, duration=60000, is_party_effect=True
+                damage_mult=1.05,
+                duration=60000,
+                is_party_effect=True,
             ),
         ),
         delay_after_parent_application=0,
+        primary_target_only=True,
     )
     _standard_finish_follow_up1 = FollowUp(
         skill=Skill(
@@ -85,6 +88,7 @@ def add_dnc_skills(skill_library):
             ),
         ),
         delay_after_parent_application=0,
+        primary_target_only=True,
     )
     _standard_remove_followup = FollowUp(
         Skill(
@@ -98,22 +102,26 @@ def add_dnc_skills(skill_library):
     )
 
     standard_finish_follow_up_damage_2 = FollowUp(
-        skill=Skill(name="Double Standard Finish", damage_spec=DamageSpec(potency=720)),
+        skill=Skill(name="Double Standard Finish", damage_spec=DamageSpec(potency=850)),
         delay_after_parent_application=530,
+        primary_target_only=False,
     )
     standard_finish_follow_up_damage_1 = FollowUp(
         skill=Skill(name="Single Standard Finish", damage_spec=DamageSpec(potency=540)),
         delay_after_parent_application=530,
+        primary_target_only=False,
     )
     standard_finish_follow_up_damage_0 = FollowUp(
         skill=Skill(name="Standard Finish", damage_spec=DamageSpec(potency=360)),
         delay_after_parent_application=530,
+        primary_target_only=False,
     )
 
     skill_library.add_skill(
         Skill(
             name="Double Standard Finish",
             is_GCD=True,
+            has_aoe=True,
             timing_spec={
                 SimConsts.DEFAULT_CONDITION: TimingSpec(
                     base_cast_time=0,
@@ -137,6 +145,7 @@ def add_dnc_skills(skill_library):
         Skill(
             name="Single Standard Finish",
             is_GCD=True,
+            has_aoe=True,
             timing_spec={
                 SimConsts.DEFAULT_CONDITION: TimingSpec(
                     base_cast_time=0,
@@ -160,6 +169,7 @@ def add_dnc_skills(skill_library):
         Skill(
             name="Standard Finish",
             is_GCD=True,
+            has_aoe=True,
             timing_spec={
                 SimConsts.DEFAULT_CONDITION: TimingSpec(
                     base_cast_time=0,
@@ -207,13 +217,14 @@ def add_dnc_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=620
             ),
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
         Skill(
             name="Fan Dance",
             is_GCD=False,
-            damage_spec=DamageSpec(potency=180),
+            damage_spec=DamageSpec(potency=150),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=620
             ),
@@ -227,13 +238,14 @@ def add_dnc_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=620
             ),
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
         Skill(
             name="Fountainfall",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=400),
+            damage_spec=DamageSpec(potency=340),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1210
             ),
@@ -247,6 +259,7 @@ def add_dnc_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=620
             ),
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
@@ -257,6 +270,7 @@ def add_dnc_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=530
             ),
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
@@ -279,10 +293,12 @@ def add_dnc_skills(skill_library):
         Skill(
             name="Fan Dance III",
             is_GCD=False,
-            damage_spec=DamageSpec(potency=220),
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=200)},
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=620
             ),
+            has_aoe=True,
+            aoe_dropoff=0.5,
         )
     )
     tech4_followup = FollowUp(
@@ -294,6 +310,7 @@ def add_dnc_skills(skill_library):
             ),
         ),
         delay_after_parent_application=125,
+        primary_target_only=True,
     )
     tech3_followup = FollowUp(
         Skill(
@@ -304,6 +321,7 @@ def add_dnc_skills(skill_library):
             ),
         ),
         delay_after_parent_application=125,
+        primary_target_only=True,
     )
     tech2_followup = FollowUp(
         Skill(
@@ -314,6 +332,7 @@ def add_dnc_skills(skill_library):
             ),
         ),
         delay_after_parent_application=125,
+        primary_target_only=True,
     )
     tech1_followup = FollowUp(
         Skill(
@@ -324,6 +343,7 @@ def add_dnc_skills(skill_library):
             ),
         ),
         delay_after_parent_application=125,
+        primary_target_only=True,
     )
 
     tech4_longest_followup = FollowUp(
@@ -335,6 +355,7 @@ def add_dnc_skills(skill_library):
             ),
         ),
         delay_after_parent_application=125,
+        primary_target_only=True,
     )
     tech3_longest_followup = FollowUp(
         Skill(
@@ -345,6 +366,7 @@ def add_dnc_skills(skill_library):
             ),
         ),
         delay_after_parent_application=125,
+        primary_target_only=True,
     )
     tech2_longest_followup = FollowUp(
         Skill(
@@ -355,6 +377,7 @@ def add_dnc_skills(skill_library):
             ),
         ),
         delay_after_parent_application=125,
+        primary_target_only=True,
     )
     tech1_longest_followup = FollowUp(
         Skill(
@@ -365,6 +388,7 @@ def add_dnc_skills(skill_library):
             ),
         ),
         delay_after_parent_application=125,
+        primary_target_only=True,
     )
 
     tech_remove_followup = FollowUp(
@@ -391,8 +415,9 @@ def add_dnc_skills(skill_library):
         Skill(
             name="Quadruple Technical Finish",
             is_GCD=True,
+            has_aoe=True,
             damage_spec={
-                SimConsts.DEFAULT_CONDITION: DamageSpec(potency=1200),
+                SimConsts.DEFAULT_CONDITION: DamageSpec(potency=1300),
                 "Buff Only": None,
                 "Remove Buff": None,
             },
@@ -413,6 +438,7 @@ def add_dnc_skills(skill_library):
         Skill(
             name="Triple Technical Finish",
             is_GCD=True,
+            has_aoe=True,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(potency=900),
                 "Buff Only": None,
@@ -435,6 +461,7 @@ def add_dnc_skills(skill_library):
         Skill(
             name="Double Technical Finish",
             is_GCD=True,
+            has_aoe=True,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(potency=720),
                 "Buff Only": None,
@@ -457,6 +484,7 @@ def add_dnc_skills(skill_library):
         Skill(
             name="Single Technical Finish",
             is_GCD=True,
+            has_aoe=True,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(potency=540),
                 "Buff Only": None,
@@ -479,6 +507,7 @@ def add_dnc_skills(skill_library):
         Skill(
             name="Technical Finish",
             is_GCD=True,
+            has_aoe=True,
             damage_spec={
                 # Default to QUADRUPLE technical finish, unless the user specifies otherwise
                 # by passing in "Log" as the skill conditional.
@@ -509,35 +538,37 @@ def add_dnc_skills(skill_library):
         Skill(
             name="Saber Dance",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=540),
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=520)},
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=440
             ),
+            has_aoe=True,
+            aoe_dropoff=0.5,
         )
     )
 
     tillana_damage_follow_up = FollowUp(
-        skill=Skill(name="Tillana", damage_spec=DamageSpec(potency=440)),
+        skill=Skill(name="Tillana", damage_spec=DamageSpec(potency=600)),
         delay_after_parent_application=840,
+        primary_target_only=False,
     )
     skill_library.add_skill(
         Skill(
             name="Tillana",
             is_GCD=True,
+            has_aoe=True,
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 gcd_base_recast_time=1500,
                 affected_by_speed_stat=False,
             ),
-            follow_up_skills=(
-                tillana_damage_follow_up,
-                _standard_finish_follow_up2,
-            ),
+            follow_up_skills=(tillana_damage_follow_up,),
         )
     )
     finishing_move_damage_follow_up = FollowUp(
-        skill=Skill(name="Finishing Move", damage_spec=DamageSpec(potency=440)),
-        delay_after_parent_application=840,
+        skill=Skill(name="Finishing Move", damage_spec=DamageSpec(potency=850)),
+        delay_after_parent_application=2200,
+        primary_target_only=False,
     )
     skill_library.add_skill(
         Skill(
@@ -552,53 +583,64 @@ def add_dnc_skills(skill_library):
                 finishing_move_damage_follow_up,
                 _standard_finish_follow_up2,
             ),
+            has_aoe=True,
         )
-    )    
+    )
     skill_library.add_skill(
         Skill(
             name="Fan Dance IV",
             is_GCD=False,
-            damage_spec=DamageSpec(potency=340),
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=300)},
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=320
             ),
+            has_aoe=True,
+            aoe_dropoff=0.5,
         )
     )
     skill_library.add_skill(
         Skill(
             name="Starfall Dance",
             is_GCD=True,
-            damage_spec=DamageSpec(
-                potency=600,
-                guaranteed_crit=ForcedCritOrDH.FORCE_YES,
-                guaranteed_dh=ForcedCritOrDH.FORCE_YES,
-            ),
+            damage_spec={
+                SimConsts.DEFAULT_CONDITION: DamageSpec(
+                    potency=600,
+                    guaranteed_crit=ForcedCritOrDH.FORCE_YES,
+                    guaranteed_dh=ForcedCritOrDH.FORCE_YES,
+                )
+            },
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=890
             ),
+            has_aoe=True,
+            aoe_dropoff=0.75,
         )
     )
     skill_library.add_skill(
         Skill(
             name="Last Dance",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=420),
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=520)},
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=440
+                base_cast_time=0, animation_lock=650, application_delay=1250
             ),
+            has_aoe=True,
+            aoe_dropoff=0.5,
         )
     )
     skill_library.add_skill(
         Skill(
             name="Dance of the Dawn",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=1000),
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=1000)},
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=440
+                base_cast_time=0, animation_lock=650, application_delay=2300
             ),
+            has_aoe=True,
+            aoe_dropoff=0.5,
         )
     )
-    
+
     # These skills do not damage, but grants resources/affects future skills.
     # Since we do not model resources YET, we just record their usage/timings but
     # not their effect.
